# coding: utf-8
from django.shortcuts import render
from django.db.models import Count, Sum, Avg
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.request import Request
from rest_framework.response import Response
from inspect_report.models import Tasks, CheckSession, RulesStat, SeatStat, ScoreStat, Round
import json
from datetime import datetime, timedelta
from config.config import TABLE_PRE, name_list
from django.views.decorators.clickjacking import xframe_options_exempt
import logging
from pypinyin import Style, pinyin
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger

from inspect_report.utils.account import get_account_info

logger = logging.getLogger(__name__)


class TasksApi(viewsets.ViewSet):
    authentication_classes = ()
    permission_classes = ()
    # permission_classes = (permissions.ValidateToken, )

    @action(['get'], detail=False)
    def obtain(self, req: Request):
        """
        查询任务列表
        :param req:
        :return:
        """
        tasks = Tasks.objects.all().order_by('-createdAt').values('id', 'name')
        # return render(req, 'inspect/index.html', {'tasks': tasks})
        return Response({'code': 0, 'msg': 'success', 'data': tasks})

    @action(['get'], detail=False)
    def seat(self, req: Request):
        """
        获取坐席列表
        :param req:
        :return:
        """
        task_id = req.GET.get('task', '')
        start_date = req.GET.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.GET.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        session_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            session_condition['task'] = task_id
        seats = SeatStat.objects.filter(**session_condition).values('agentName')
        return_data = []
        for agent in seats:
            if agent not in return_data:
                return_data.append(agent)
        return Response({'code': 0, 'msg': 'success', 'data': return_data})

    @action(['post'], detail=False)
    def rule(self, req: Request):
        """
        获取违规项分析
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        agent_name = req.data.get('agentName', '')
        start_date = req.data.get('start_date', (datetime.now()+timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        task_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        data_sort = []
        return_data = {}
        if task_id:
            task_condition['task'] = task_id
        if agent_name:
            task_condition['agentName'] = agent_name
        # tasks = RulesStat.objects.filter(**task_condition).values('rule', 'sessionCollectionId', 'rule_num')
        tasks = RulesStat.objects.all().filter(**task_condition) \
            .extra(select={'rule': "rule", 'sessionCollectionId': 'sessionCollectionId'}) \
            .values('rule', 'sessionCollectionId').annotate(rule_num=Count('id')).order_by('-rule_num')
        for t in tasks:
            name = t['rule']
            if name in return_data.keys():
                return_data[name]['count'] += int(t['rule_num'])
            else:
                return_data[name] = {'count': int(t['rule_num']), 'tables': []}
            if t['sessionCollectionId'] not in return_data[name]['tables']:
                return_data[name]['tables'].append(t['sessionCollectionId'])

        for k, v in return_data.items():
            v['rule'] = k
            data_sort.append(v)
        # data_sort = sorted(data_sort, key=lambda x: x['count'], reverse=True)
        return Response({'code': 0, 'msg': 'success', 'data': data_sort})

    @action(['post'], detail=False)
    def seat_session(self, req: Request):
        """
        坐席违规分析-按照会话
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        num = req.data.get('num', '10')
        start_date = req.data.get('start_date', (datetime.now()+timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date + ' 23:59:59'}
        if task_id:
            task_condition['name__startswith'] = task_id
        tasks = Tasks.objects.filter(**task_condition).values('id', 'sessionCollectionId')
        task_dict = {}
        for t in tasks:
            if t['sessionCollectionId'] in task_dict.keys():
                task_dict[t['sessionCollectionId']].append(t['id'])
            else:
                task_dict[t['sessionCollectionId']] = [t['id'], ]
        return_data = {}
        for k, v in task_dict.items():
            table_name = TABLE_PRE + k
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId__in': v}
            checks = tn.objects.filter(**session_condition).values('agentName')
            for check in checks:
                agent_name = check['agentName']
                if agent_name:
                    if agent_name in return_data.keys():
                        return_data[agent_name] += 1
                    else:
                        return_data[agent_name] = 1
        data_max = sorted(return_data.items(), key=lambda item: item[1], reverse=False)
        data_max = data_max[-int(num):]
        data_max_return = {}
        for dm in data_max:
            data_max_return[dm[0]] = dm[1]
        return Response({'code': 0, 'msg': 'success', 'data': data_max_return})

    @action(['post'], detail=False)
    def seat_score(self, req: Request):
        """
        坐席违规分析-按照得分
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        num = req.data.get('num', '10')
        start_date = req.data.get('start_date', (datetime.now()+timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date + ' 23:59:59'}
        if task_id:
            task_condition['name__startswith'] = task_id
        tasks = Tasks.objects.filter(**task_condition).values('id', 'sessionCollectionId')
        task_dict = {}
        for t in tasks:
            if t['sessionCollectionId'] in task_dict.keys():
                task_dict[t['sessionCollectionId']].append(t['id'])
            else:
                task_dict[t['sessionCollectionId']] = [t['id'], ]
        return_data = {}
        for k, v in task_dict.items():
            table_name = TABLE_PRE + k
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId__in': v}
            checks = tn.objects.filter(**session_condition).values('agentName', 'score')
            for check in checks:
                agent_name = check['agentName']
                if agent_name:
                    if agent_name in return_data.keys():
                        return_data[agent_name] += check['score']
                    else:
                        return_data[agent_name] = check['score']
        data_max = sorted(return_data.items(), key=lambda item: item[1], reverse=False)
        data_max = data_max[:int(num)]
        data_max_return = {}
        for dm in data_max:
            data_max_return[dm[0]] = dm[1]
        return Response({'code': 0, 'msg': 'success', 'data': data_max_return})

    @action(['post'], detail=False)
    def seat_rule(self, req: Request):
        """
        坐席违规分析-按照得分
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        agent_name = req.data.get('agentName', '')
        sort = req.data.get('sort', 'des')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        start_date = req.data.get('start_date', (datetime.now()+timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        task_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            task_condition['task'] = task_id
        if agent_name:
            task_condition['agentName'] = agent_name
        if sort == 'des':
            seats = SeatStat.objects.filter(**task_condition).extra(select={'agentName': 'agentName'}) \
                .values('agentName').annotate(remainTime=Sum('remainTime'), validate_session=Sum('validate_session'),
                                              total_session=Sum('total_session')).order_by('-validate_session')

        else:
            seats = SeatStat.objects.filter(**task_condition).extra(select={'agentName': 'agentName'}) \
                .values('agentName').annotate(remainTime=Sum('remainTime'), validate_session=Sum('validate_session'),
                                              total_session=Sum('total_session')).order_by('validate_session')
        paginator = Paginator(seats, page_size)
        total_count = paginator.count
        try:
            seats = paginator.page(page)
        except PageNotAnInteger:
            seats = paginator.page(1)
        except EmptyPage:
            seats = paginator.page(paginator.num_pages)
        return_data = []
        for s in seats:
            detail = {'agentName': s['agentName'], 'validate_session': s['validate_session'],
                      'remainTime': s['remainTime'], 'total_session': s['total_session'],
                      'ratio': round(s['validate_session']/s['total_session'], 2)}
            return_data.append(detail)
        if sort == 'asc':
            data_sort = sorted(return_data, key=lambda x: x['ratio'])
            for i in range(len(data_sort)):
                data_sort[i]['ranking'] = total_count - (int(page)-1)*int(page_size) - i
                data_sort[i]['ratio'] = '{0}%'.format(int(data_sort[i]['ratio'] * 100))
        else:
            data_sort = sorted(return_data, key=lambda x: x['ratio'], reverse=True)
            for i in range(len(data_sort)):
                data_sort[i]['ranking'] = (int(page)-1)*int(page_size) + i + 1
                data_sort[i]['ratio'] = '{0}%'.format(int(data_sort[i]['ratio'] * 100))
        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': data_sort})

    @action(['post'], detail=False)
    @get_account_info
    def static(self, req: Request):
        """
        获取违规项分析
        :param req:
        :return:
        """
        username = req.data.get('username', '')
        # logger.info('username获取: ' + username)
        task_id = req.data.get('task', '')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        session_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            session_condition['task'] = task_id
        if username in name_list:
            session_condition['task'] = username
        seat_data = SeatStat.objects.filter(**session_condition).aggregate(
            validate_session_sum=Sum('validate_session'), total_session_sum=Sum('total_session'))
        avg_score = ScoreStat.objects.filter(**session_condition).aggregate(score_avg=Round(Avg('score'), 2))
        return_data = {'validate_session': seat_data['validate_session_sum'],
                       'total_session': seat_data['total_session_sum']}
        if seat_data['total_session_sum']:
            return_data['ratio'] = round(seat_data['validate_session_sum']/seat_data['total_session_sum'], 2)
            return_data['avg_score'] = avg_score['score_avg']
        else:
            return_data['ratio'] = 0.0
            return_data['avg_score'] = 0.0
        return Response({'code': 0, 'msg': 'success', 'data': return_data, 'username': username})

    @action(['post'], detail=False)
    def static_date(self, req: Request):
        """
        获取违规项分析
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-6)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date + ' 23:59:59'}
        if task_id:
            task_condition['name__startswith'] = task_id
        tasks = Tasks.objects.filter(**task_condition).values('id', 'sessionCollectionId')
        task_dict = {}
        for t in tasks:
            if t['sessionCollectionId'] in task_dict.keys():
                task_dict[t['sessionCollectionId']].append(t['id'])
            else:
                task_dict[t['sessionCollectionId']] = [t['id'], ]
        return_data = {}
        for k, v in task_dict.items():
            table_name = TABLE_PRE + k
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId__in': v}
            checks = tn.objects.filter(**session_condition).values('violationRuleCount', 'createdAt')
            for check in checks:
                date = check['createdAt'].strftime('%Y-%m-%d')
                if date in return_data.keys():
                    return_data[date]['total_session'] += 1
                    if check['violationRuleCount'] > 0:
                        return_data[date]['validate_session'] += 1
                else:
                    if check['violationRuleCount'] > 0:
                        return_data[date] = {'total_session': 1, 'validate_session': 1}
                    else:
                        return_data[date] = {'total_session': 1, 'validate_session': 0}
        data_sort = []
        for k, v in return_data.items():
            # return_data[k]['ratio'] = round(v['validate_session']/v['total_session'], 2)
            if v['total_session']:
                v['ratio'] = round(v['validate_session']/v['total_session'], 2)
            else:
                v['ratio'] = 0
            v['date'] = k
            data_sort.append(v)
        data_sort = sorted(data_sort, key=lambda x: x['date'], reverse=True)
        return Response({'code': 0, 'msg': 'success', 'data': data_sort})

    @action(['post'], detail=False)
    def seat_check(self, req: Request):
        """
        坐席绩效考核汇总
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        agent_name = req.data.get('agentName', '')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date + ' 23:59:59'}
        if task_id:
            task_condition['name__startswith'] = task_id
        tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
        task_dict = {}
        task_name_dict = {}
        for t in tasks:
            task_name_dict[t['id']] = t['name']
            if t['sessionCollectionId'] in task_dict.keys():
                task_dict[t['sessionCollectionId']].append(t['id'])
            else:
                task_dict[t['sessionCollectionId']] = [t['id'], ]
        return_data = []
        total_count = 0
        for k, v in task_dict.items():
            # session_collection = t.sessionCollectionId
            table_name = TABLE_PRE + k
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId__in': v}
            if agent_name:
                session_condition['agentName'] = agent_name
            checks = tn.objects.filter(**session_condition).values('id', 'createdAt', 'agentName', 'extra', 'taskId',
                                                                   'remainTime', 'startTime', 'closeTime',
                                                                   'scoreItemRecord', 'sessionId')
            paginator = Paginator(checks, page_size)
            total_count += paginator.count
            try:
                seats = paginator.page(page)
            except PageNotAnInteger:
                seats = paginator.page(1)
            except EmptyPage:
                seats = paginator.page(paginator.num_pages)

            for check in seats:
                result = check['scoreItemRecord']
                t_name = task_name_dict[check['taskId']]
                total_score = 100
                extra = json.loads(check['extra'])
                remain = 0
                if check['startTime'] and check['closeTime']:
                    start = datetime.strptime(check['startTime'], '%Y-%m-%d %H:%M:%S').timestamp()
                    close = datetime.strptime(check['closeTime'], '%Y-%m-%d %H:%M:%S').timestamp()
                    remain = int(close - start)
                f_name = extra['filename'] if extra and 'filename' in extra.keys() else ''
                detail = {'id': check['id'], 'sessionId': check['sessionId'], 'createdAt': check['createdAt'],
                          'area': t_name.split('_')[0], 'agentName': check['agentName'], 'filename': f_name,
                          'remainTime': remain, 'sessionCollectionId': k, 'taskId': check['taskId']}
                rule_detail = {'fwyy': 15, 'kcb': 5, 'jsy': 3, 'fwtd': 5, 'yssb': 5, 'jysb': 5, 'yycl': 10,
                               'ywcc': 10, 'yyjlz': 10, 'fwjs': 10, 'wtgbj': 2, 'cgjxxhs': 20, 'wgzlf': 100, 'mgc': 100}
                if result:
                    data = json.loads(result)
                    for d in data:
                        if 'scoreItemName' in d.keys() and 'score' in d.keys():
                            item_score = 0 if d['score'] and d['score'] > 0 else 1
                            name_py = pinyin(d['scoreItemName'], style=Style.FIRST_LETTER, strict=False)
                            item_name = ''.join([x[0] for x in name_py])
                            # detail[item_name] = {d['scoreItemName']: item_score}
                            if item_name in rule_detail.keys():
                                if item_score == 0:
                                    total_score -= rule_detail[item_name]
                                rule_detail[item_name] = item_score
                for kk, vv in rule_detail.items():
                    if vv > 1:
                        rule_detail[kk] = 1
                if rule_detail['wgzlf'] == 0 or rule_detail['mgc'] == 0:
                    total_score = 0
                detail.update(rule_detail)
                detail['total_score'] = total_score
                return_data.append(detail)
        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': return_data})

    @action(['post'], detail=False)
    def seat_area(self, req: Request):
        """
        地市坐席成绩分析
        :param req:
        :return:
        """
        task_id = req.data.get('task', '')
        agent_name = req.data.get('agentName', '')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        sort = req.data.get('sort', '-avg_score')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        task_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            task_condition['task'] = task_id
        if agent_name:
            task_condition['agentName'] = agent_name
        # , 'total_session', 'validate_num', 'validate_session', 'validate_zero'
        rules = ScoreStat.objects.filter(**task_condition).extra(select={'area': "task", 'agentName': 'agentName'})\
            .values('area', 'agentName').annotate(avg_score_svc=Round(Avg('service_score'), 2),
                                                  avg_score_bus=Round(Avg('business_score'), 2),
                                                  avg_score=Round(Avg('score'), 2), total_session=Sum('total_session'),
                                                  validate_num=Sum('validate_num'), validate_zero=Sum('validate_zero'))\
            .order_by(sort)
        paginator = Paginator(rules, page_size)
        total_count = paginator.count
        try:
            seats = paginator.page(page)
        except PageNotAnInteger:
            seats = paginator.page(1)
        except EmptyPage:
            seats = paginator.page(paginator.num_pages)

        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': seats.object_list})

    @action(['post'], detail=False)
    @get_account_info
    def static_rule(self, req: Request):
        """
        首页概述-违规项统计
        :param req:
        :return:
        """
        username = req.data.get('username', '')
        task_id = req.data.get('task', '')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date + ' 23:59:59'}
        if task_id:
            task_condition['name__startswith'] = task_id
        if username in name_list:
            task_condition['name__startswith'] = username
        tasks = Tasks.objects.filter(**task_condition).values('id', 'sessionCollectionId')
        task_dict = {}
        for t in tasks:
            if t['sessionCollectionId'] in task_dict.keys():
                task_dict[t['sessionCollectionId']].append(t['id'])
            else:
                task_dict[t['sessionCollectionId']] = [t['id'], ]
        return_data = {}
        call_count = 0
        for k, v in task_dict.items():
            table_name = TABLE_PRE + k
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId__in': v, 'violationRuleCount__gt': 0}
            validate_all = tn.objects.filter(**session_condition).aggregate(Count("id"))
            call_count += validate_all['id__count']

        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        task_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            task_condition['task'] = task_id
        # tasks = RulesStat.objects.filter(**task_condition).values('rule', 'sessionCollectionId', 'rule_num')
        tasks = RulesStat.objects.all().filter(**task_condition)\
            .extra(select={'rule': "rule", 'sessionCollectionId': 'sessionCollectionId'})\
            .values('rule', 'sessionCollectionId').annotate(rule_num=Count('id')).order_by('-rule_num')
        for t in tasks:
            name = t['rule']
            if name in return_data.keys():
                return_data[name]['count'] += int(t['rule_num'])
            else:
                return_data[name] = {'count': int(t['rule_num']), 'tables': []}
            if t['sessionCollectionId'] not in return_data[name]['tables']:
                return_data[name]['tables'].append(t['sessionCollectionId'])
        data_sort = []
        for k, v in return_data.items():
            v['rule'] = k
            v['ratio'] = round(v['count']/call_count, 2) if call_count else 0
            v['ratio'] = '{0}%'.format(int(v['ratio'] * 100))
            v['call_count'] = call_count
            data_sort.append(v)
        # data_sort = sorted(data_sort, key=lambda x: x['count'], reverse=True)
        return Response({'code': 0, 'msg': 'success', 'data': data_sort, 'username': username})

    @action(['post'], detail=False)
    def rule_detail(self, req: Request):
        """
        首页概述-违规项统计
        :param req:
        :return:
        """
        tables = req.data.get('tables', '')
        rule_name = req.data.get('rule', '')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        if not isinstance(tables, list):
            table_list = json.loads(tables)
        else:
            table_list = tables
        session_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date, 'rule': rule_name,
                             'sessionCollectionId__in': table_list}
        checks = RulesStat.objects.filter(**session_condition).values('agentName', 'customName', 'remainTime', 'score',
                                                                      'sessionCollectionId', 'sessionId', 'taskId')
        paginator = Paginator(checks, page_size)
        total_count = paginator.count
        try:
            seats = paginator.page(page)
        except PageNotAnInteger:
            seats = paginator.page(1)
        except EmptyPage:
            seats = paginator.page(paginator.num_pages)
        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': seats.object_list})

    @action(['post'], detail=False)
    @get_account_info
    def static_score(self, req: Request):
        """
        概览-地市得分统计
        :param req:
        :return:
        """
        username = req.data.get('username', '')
        task_id = req.data.get('task', '')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        sort = req.data.get('sort', '-avg_score')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + + timedelta(days=1)).date()
        task_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if task_id:
            task_condition['task'] = task_id
        if username in name_list:
            task_condition['task'] = username
        rules = ScoreStat.objects.filter(**task_condition).extra(select={'area': "task"}) \
            .values('area').annotate(avg_score_svc=Round(Avg('service_score'), 2),
                                     avg_score_bus=Round(Avg('business_score'), 2),
                                     avg_score=Round(Avg('score'), 2), total_session=Sum('total_session'),
                                     validate_num=Sum('validate_num'), validate_zero=Sum('validate_zero')) \
            .order_by(sort)
        paginator = Paginator(rules, page_size)
        total_count = paginator.count
        try:
            seats = paginator.page(page)
        except PageNotAnInteger:
            seats = paginator.page(1)
        except EmptyPage:
            seats = paginator.page(paginator.num_pages)

        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': seats.object_list, 'username': username})

    @action(['post'], detail=False)
    def score_detail(self, req: Request):
        """
        坐席得分列表
        :param req:
        :return:
        """
        agent_name = req.data.get('agentName', '')
        area = req.data.get('task', '')
        page = req.data.get('page', '1')
        page_size = req.data.get('page_size', '10')
        start_date = req.data.get('start_date', (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d'))
        end_date = req.data.get('end_date', datetime.now().strftime('%Y-%m-%d'))
        q_start_date = datetime.strptime(start_date, '%Y-%m-%d').date()
        q_end_date = (datetime.strptime(end_date, '%Y-%m-%d') + timedelta(days=1)).date()

        session_condition = {'create_date__gte': q_start_date, 'create_date__lt': q_end_date}
        if agent_name:
            session_condition['agentName'] = agent_name
        if area:
            session_condition['task'] = area

        checks = RulesStat.objects.filter(**session_condition)\
            .extra(select={'sessionCollectionId': 'sessionCollectionId'})\
            .values('agentName', 'customName', 'remainTime', 'score', 'sessionCollectionId', 'sessionId', 'taskId')\
            .distinct()
        paginator = Paginator(checks, page_size)
        total_count = paginator.count
        try:
            seats = paginator.page(page)
        except PageNotAnInteger:
            seats = paginator.page(1)
        except EmptyPage:
            seats = paginator.page(paginator.num_pages)
        return Response({'code': 0, 'msg': 'success', 'count': total_count, 'data': seats.object_list})


@xframe_options_exempt
def rule(request):
    return render(request, 'inspect/rule.html')


@xframe_options_exempt
def seat(request):
    return render(request, 'inspect/seat.html')


@xframe_options_exempt
def group(request):
    return render(request, 'inspect/group.html')


@xframe_options_exempt
def score(request):
    return render(request, 'inspect/score.html')


@xframe_options_exempt
def check(request):
    return render(request, 'inspect/seat_check.html')
