import json
import logging

import requests

from requests.cookies import RequestsCookieJar

from functools import wraps
from rest_framework.request import Request
from rest_framework.response import Response

from config.config import USER_INFO_URL

logger = logging.getLogger(__name__)


def transfer_cookie(cookies):
    """
    将cookie加入cookie_jar对象
    :param cookies: dict
    :return: cookie_jar
    """
    cookie_jar = RequestsCookieJar()
    for key, value in cookies.items():
        cookie_jar.set(key, value)
    return cookie_jar


def get_account_info(func):
    """
    装饰器，对请求进行权限验证
    :param func:
    :return:
    """
    @wraps(func)
    def account_info(obj, req: Request, *args, **kw):
        # logger.info('req中的data为: ' + json.dumps(req.COOKIES))
        cookie_jar = transfer_cookie(req.COOKIES)
        info = requests.get(USER_INFO_URL, cookies=cookie_jar)
        # logger.info('req中的query_params为: ', req.query_params)
        try:
            if info.json()['code'] != 200:
                logger.info('未能获取用户信息: ' + info.text)
                return Response({'code': -1, 'msg': '未能获取用户信息'})
        except Exception:
            logger.info('未能获取用户信息: ' + info.text)
            return Response({'code': -1, 'msg': '未能获取用户信息'})
        req.data['username'] = info.json()['data']['userInfo']['name']
        return func(obj, req, *args, **kw)

    return account_info

# get_account_info()
